paidiverpy.utils.static.js
==========================

.. py:module:: paidiverpy.utils.static.js

.. autoapi-nested-parse::

   
   Static js files for paidiverpy.
















   ..
       !! processed by numpydoc !!


